This is the package that contains all historical information regarding the connection to Eodhistorical data and other outside sources.
Contents:
    1. fxconvert
    2. investment category
    3. loadstock
    4. Get exchange info
    5. load historical data

